@@ -1,20 +1,29 @@
 // Copyright (C) 2021 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
-#include <QDateTime>
-#include <QMap>
-#include <QRandomGenerator>
-#include <QGeoPositionInfo>
-#include <QJniEnvironment>
-#include <QJniObject>
-#include <QLoggingCategory>
-#include <QtCore/private/qandroidextras_p.h>
-#include <QCoreApplication>
-#include <android/log.h>
+#include "jnipositioning.h"
 #include "qgeopositioninfosource_android_p.h"
 #include "qgeosatelliteinfosource_android_p.h"
-#include "jnipositioning.h"
+#include <QtPositioning/QGeoPositionInfo>
+#include <QtCore/QDateTime>
+#include <QtCore/QMap>
+#include <QtCore/QRandomGenerator>
+#include <QtCore/QJniEnvironment>
+#include <QtCore/QJniObject>
+#include <QtCore/QLoggingCategory>
+#include <QtCore/QPermission>
+#include <QtCore/QCoreApplication>
+#include <QtCore/QTimeZone>
+#include <QtCore/QSet>
+#include <android/log.h>
 
+Q_DECLARE_JNI_CLASS(QtPositioning, "org/qtproject/qt/android/positioning/QtPositioning")
+Q_DECLARE_JNI_CLASS(GnssStatus, "android/location/GnssStatus")
+Q_DECLARE_JNI_CLASS(Location, "android/location/Location")
+
+using namespace Qt::StringLiterals;
+
+template<typename T>
 class GlobalClassRefWrapper
 {
 public:
@@ -28,7 +37,7 @@ public:
         }
     }
 
-    bool init(const char *className)
+    bool init()
     {
         QJniEnvironment env;
         if (env.jniEnv()) {
@@ -37,7 +46,7 @@ public:
                 m_classRef = nullptr;
             }
 
-            m_classRef = env.findClass(className); // it returns global ref!
+            m_classRef = env.findClass<T>(); // it returns global ref!
         }
         return m_classRef != nullptr;
     }
@@ -48,7 +57,7 @@ private:
     jclass m_classRef = nullptr;
 };
 
-static GlobalClassRefWrapper positioningClass;
+static GlobalClassRefWrapper<QtJniTypes::QtPositioning> positioningClass;
 
 static jmethodID providerListMethodId;
 static jmethodID lastKnownPositionMethodId;
@@ -77,7 +86,7 @@ public:
     {
         m_gnssStatusObject = nullptr;
         if (QNativeInterface::QAndroidApplication::sdkVersion() > 23) {
-            m_gnssStatusObject = QJniEnvironment().findClass("android/location/GnssStatus");
+            m_gnssStatusObject = QJniEnvironment().findClass<QtJniTypes::GnssStatus>();
             if (!m_gnssStatusObject)
                 return false;
         }
@@ -181,8 +190,13 @@ namespace AndroidPositioning {
         if (!env.jniEnv())
             return ret;
         QJniObject jniProvidersObj =
-                QJniObject::callStaticObjectMethod(positioningClass(), providerListMethodId);
+                QJniObject::callStaticMethod<jobject>(positioningClass(), providerListMethodId);
         jintArray jProviders = jniProvidersObj.object<jintArray>();
+        if (!jProviders) {
+            // Work-around for QTBUG-116645
+            __android_log_print(ANDROID_LOG_INFO, logTag, "Got null providers array!");
+            return ret;
+        }
         jint *providers = env->GetIntArrayElements(jProviders, nullptr);
         const int size = env->GetArrayLength(jProviders);
         for (int i = 0; i < size; i++) {
@@ -206,7 +220,7 @@ namespace AndroidPositioning {
         return ret;
     }
 
-    QGeoPositionInfo positionInfoFromJavaLocation(const jobject &location)
+    QGeoPositionInfo positionInfoFromJavaLocation(const jobject &location, bool useAltConverter)
     {
         QGeoPositionInfo info;
 
@@ -226,12 +240,25 @@ namespace AndroidPositioning {
             if (!qFuzzyIsNull(value))
                 coordinate.setAltitude(value);
         }
+        // MSL altitude, available in API Level 34+.
+        // In API Level 34 it was available only if we manually added it.
+        // In API Level 35 (and potentially later), it's automatically added
+        // to the location object, so we need to use it *only* when the user
+        // set the relevant plugin parameter.
+        if (useAltConverter && QNativeInterface::QAndroidApplication::sdkVersion() >= 34) {
+            attributeExists = jniObject.callMethod<jboolean>("hasMslAltitude");
+            if (attributeExists) {
+                const jdouble value = jniObject.callMethod<jdouble>("getMslAltitudeMeters");
+                if (!qFuzzyIsNull(value))
+                    coordinate.setAltitude(value);
+            }
+        }
 
         info.setCoordinate(coordinate);
 
         // time stamp
         const jlong timestamp = jniObject.callMethod<jlong>("getTime");
-        info.setTimestamp(QDateTime::fromMSecsSinceEpoch(timestamp, Qt::UTC));
+        info.setTimestamp(QDateTime::fromMSecsSinceEpoch(timestamp, QTimeZone::UTC));
 
         // horizontal accuracy
         attributeExists = jniObject.callMethod<jboolean>("hasAccuracy");
@@ -278,10 +305,18 @@ namespace AndroidPositioning {
         return info;
     }
 
+    using UniqueId = std::pair<int, int>;
+    static UniqueId getUid(const QGeoSatelliteInfo &info)
+    {
+        return std::make_pair(static_cast<int>(info.satelliteSystem()),
+                              info.satelliteIdentifier());
+    }
+
     QList<QGeoSatelliteInfo> satelliteInfoFromJavaLocation(JNIEnv *jniEnv,
                                                            jobjectArray satellites,
                                                            QList<QGeoSatelliteInfo>* usedInFix)
     {
+        QSet<UniqueId> uids;
         QList<QGeoSatelliteInfo> sats;
         jsize length = jniEnv->GetArrayLength(satellites);
         for (int i = 0; i<length; i++) {
@@ -332,7 +367,12 @@ namespace AndroidPositioning {
             // determining the position.
             const jboolean inFix = jniObj.callMethod<jboolean>("usedInFix");
 
+            const UniqueId id = getUid(info);
+            if (uids.contains(id))
+                continue;
+
             sats.append(info);
+            uids.insert(id);
 
             if (inFix)
                 usedInFix->append(info);
@@ -346,6 +386,7 @@ namespace AndroidPositioning {
     {
         QJniObject jniStatus(gnssStatus);
         QList<QGeoSatelliteInfo> sats;
+        QSet<UniqueId> uids;
 
         const int satellitesCount = jniStatus.callMethod<jint>("getSatelliteCount");
         for (int i = 0; i < satellitesCount; ++i) {
@@ -354,31 +395,36 @@ namespace AndroidPositioning {
             // signal strength - this is actually a carrier-to-noise density,
             // but the values are very close to what was previously returned by
             // getSnr() method of the GpsSatellite API.
-            const jfloat cn0 = jniStatus.callMethod<jfloat>("getCn0DbHz", "(I)F", i);
+            const jfloat cn0 = jniStatus.callMethod<jfloat>("getCn0DbHz", i);
             info.setSignalStrength(static_cast<int>(cn0));
 
             // satellite system
             const jint constellationType =
-                    jniStatus.callMethod<jint>("getConstellationType", "(I)I", i);
+                    jniStatus.callMethod<jint>("getConstellationType", i);
             info.setSatelliteSystem(ConstellationMapper::toSatelliteSystem(constellationType));
 
             // satellite identifier
-            const jint svId = jniStatus.callMethod<jint>("getSvid", "(I)I", i);
+            const jint svId = jniStatus.callMethod<jint>("getSvid", i);
             info.setSatelliteIdentifier(svId);
 
             // azimuth
-            const jfloat azimuth = jniStatus.callMethod<jfloat>("getAzimuthDegrees", "(I)F", i);
+            const jfloat azimuth = jniStatus.callMethod<jfloat>("getAzimuthDegrees", i);
             info.setAttribute(QGeoSatelliteInfo::Azimuth, static_cast<qreal>(azimuth));
 
             // elevation
-            const jfloat elevation = jniStatus.callMethod<jfloat>("getElevationDegrees", "(I)F", i);
+            const jfloat elevation = jniStatus.callMethod<jfloat>("getElevationDegrees", i);
             info.setAttribute(QGeoSatelliteInfo::Elevation, static_cast<qreal>(elevation));
 
             // Used in fix - true if this satellite is actually used in
             // determining the position.
-            const jboolean inFix = jniStatus.callMethod<jboolean>("usedInFix", "(I)Z", i);
+            const jboolean inFix = jniStatus.callMethod<jboolean>("usedInFix", i);
+
+            const UniqueId id = getUid(info);
+            if (uids.contains(id))
+                continue;
 
             sats.append(info);
+            uids.insert(id);
 
             if (inFix)
                 usedInFix->append(info);
@@ -387,22 +433,28 @@ namespace AndroidPositioning {
         return sats;
     }
 
-    QGeoPositionInfo lastKnownPosition(bool fromSatellitePositioningMethodsOnly)
+    QGeoPositionInfo lastKnownPosition(bool fromSatellitePositioningMethodsOnly,
+                                       bool useAltitudeConverter)
     {
         QJniEnvironment env;
         if (!env.jniEnv())
             return QGeoPositionInfo();
 
-        if (!requestionPositioningPermissions())
+        const auto accuracy = fromSatellitePositioningMethodsOnly
+                ? AccuracyType::Precise
+                : AccuracyType::Any;
+
+        if (!hasPositioningPermissions(accuracy))
             return {};
 
-        QJniObject locationObj = QJniObject::callStaticObjectMethod(
-                positioningClass(), lastKnownPositionMethodId, fromSatellitePositioningMethodsOnly);
+        QJniObject locationObj = QJniObject::callStaticMethod<jobject>(
+                positioningClass(), lastKnownPositionMethodId, fromSatellitePositioningMethodsOnly,
+                useAltitudeConverter);
         jobject location = locationObj.object();
         if (location == nullptr)
             return QGeoPositionInfo();
 
-        const QGeoPositionInfo info = positionInfoFromJavaLocation(location);
+        const QGeoPositionInfo info = positionInfoFromJavaLocation(location, useAltitudeConverter);
 
         return info;
     }
@@ -418,6 +470,17 @@ namespace AndroidPositioning {
         return providerSelection;
     }
 
+    static AccuracyTypes
+    accuracyFromPositioningMethods(QGeoPositionInfoSource::PositioningMethods m)
+    {
+        AccuracyTypes types = AccuracyType::None;
+        if (m & QGeoPositionInfoSource::NonSatellitePositioningMethods)
+            types |= AccuracyType::Approximate;
+        if (m & QGeoPositionInfoSource::SatellitePositioningMethods)
+            types |= AccuracyType::Precise;
+        return types;
+    }
+
     QGeoPositionInfoSource::Error startUpdates(int androidClassKey)
     {
         QJniEnvironment env;
@@ -427,13 +490,15 @@ namespace AndroidPositioning {
         QGeoPositionInfoSourceAndroid *source = AndroidPositioning::idToPosSource()->value(androidClassKey);
 
         if (source) {
-            if (!requestionPositioningPermissions())
+            const auto preferredMethods = source->preferredPositioningMethods();
+            const auto accuracy = accuracyFromPositioningMethods(preferredMethods);
+            if (!hasPositioningPermissions(accuracy))
                 return QGeoPositionInfoSource::AccessError;
 
             int errorCode = QJniObject::callStaticMethod<jint>(
                     positioningClass(), startUpdatesMethodId, androidClassKey,
-                    positioningMethodToInt(source->preferredPositioningMethods()),
-                    source->updateInterval());
+                    positioningMethodToInt(preferredMethods),
+                    source->updateInterval(), source->useAltitudeConverter());
             switch (errorCode) {
             case 0:
             case 1:
@@ -455,7 +520,7 @@ namespace AndroidPositioning {
                                            androidClassKey);
     }
 
-    QGeoPositionInfoSource::Error requestUpdate(int androidClassKey)
+    QGeoPositionInfoSource::Error requestUpdate(int androidClassKey, int timeout)
     {
         QJniEnvironment env;
         if (!env.jniEnv())
@@ -464,12 +529,15 @@ namespace AndroidPositioning {
         QGeoPositionInfoSourceAndroid *source = AndroidPositioning::idToPosSource()->value(androidClassKey);
 
         if (source) {
-            if (!requestionPositioningPermissions())
+            const auto preferredMethods = source->preferredPositioningMethods();
+            const auto accuracy = accuracyFromPositioningMethods(preferredMethods);
+            if (!hasPositioningPermissions(accuracy))
                 return QGeoPositionInfoSource::AccessError;
 
             int errorCode = QJniObject::callStaticMethod<jint>(
                     positioningClass(), requestUpdateMethodId, androidClassKey,
-                    positioningMethodToInt(source->preferredPositioningMethods()));
+                    positioningMethodToInt(preferredMethods),
+                    timeout, source->useAltitudeConverter());
             switch (errorCode) {
             case 0:
             case 1:
@@ -492,7 +560,9 @@ namespace AndroidPositioning {
         QGeoSatelliteInfoSourceAndroid *source = AndroidPositioning::idToSatSource()->value(androidClassKey);
 
         if (source) {
-            if (!requestionPositioningPermissions())
+            // Satellite Info request does not make sense with Approximate
+            // location permissions, so always check for Precise
+            if (!hasPositioningPermissions(AccuracyType::Precise))
                 return QGeoSatelliteInfoSource::AccessError;
 
             int interval = source->updateInterval();
@@ -517,47 +587,37 @@ namespace AndroidPositioning {
         return QGeoSatelliteInfoSource::UnknownSourceError;
     }
 
-    bool requestionPositioningPermissions()
+
+    bool hasPositioningPermissions(AccuracyTypes accuracy)
     {
-        // If the code is running as a service, we can't request permissions.
-        // We can only check if we have the needed permissions. Also make sure
-        // to request the background location permissions.
-        if (!QNativeInterface::QAndroidApplication::isActivityContext()) {
-            const auto permission = QtAndroidPrivate::PreciseBackgroundLocation;
-            const auto result = QtAndroidPrivate::checkPermission(permission).result();
-            if (result != QtAndroidPrivate::Authorized) {
-                qCWarning(lcPositioning)
-                        << "Position data not available due to missing permission" << permission;
-            }
-            return result == QtAndroidPrivate::Authorized;
-        } else {
-            // Running from a normal Activity. Checking and requesting the
-            // permissions if necessary.
+        QLocationPermission permission;
 
-            // Android v23+ requires runtime permission check and requests
-            const auto permission = QtAndroidPrivate::PreciseLocation;
-            auto checkFuture = QtAndroidPrivate::checkPermission(permission);
-            if (checkFuture.result() == QtAndroidPrivate::Denied) {
-                auto requestFuture = QtAndroidPrivate::requestPermission(permission);
-                if (requestFuture.result() != QtAndroidPrivate::Authorized) {
-                    qCWarning(lcPositioning)
-                            << "Position data not available due to missing permission"
-                            << permission;
-                    return false;
-                }
-            }
+        // The needed permission depends on whether we run as a service or as an activity
+        if (!QNativeInterface::QAndroidApplication::isActivityContext())
+            permission.setAvailability(QLocationPermission::Always); // background location
 
-            return true;
+        bool permitted = false;
+        if (accuracy & AccuracyType::Precise) {
+            permission.setAccuracy(QLocationPermission::Precise);
+            permitted = qApp->checkPermission(permission) == Qt::PermissionStatus::Granted;
         }
+        if (accuracy & AccuracyType::Approximate) {
+            permission.setAccuracy(QLocationPermission::Approximate);
+            permitted |= qApp->checkPermission(permission) == Qt::PermissionStatus::Granted;
+        }
+
+        if (!permitted)
+            qCWarning(lcPositioning) << "Position data not available due to missing permission";
+
+        return permitted;
     }
 }
 
-static void positionUpdated(JNIEnv *env, jobject thiz, jobject location,
+static void positionUpdated(JNIEnv *env, jobject thiz, QtJniTypes::Location location,
                             jint androidClassKey, jboolean isSingleUpdate)
 {
     Q_UNUSED(env);
     Q_UNUSED(thiz);
-    QGeoPositionInfo info = AndroidPositioning::positionInfoFromJavaLocation(location);
 
     QGeoPositionInfoSourceAndroid *source = AndroidPositioning::idToPosSource()->value(androidClassKey);
     if (!source) {
@@ -565,6 +625,10 @@ static void positionUpdated(JNIEnv *env, jobject thiz, jobject location,
         return;
     }
 
+    const bool useAltitudeConverter = source->useAltitudeConverter();
+    QGeoPositionInfo info =
+            AndroidPositioning::positionInfoFromJavaLocation(location.object(), useAltitudeConverter);
+
     //we need to invoke indirectly as the Looper thread is likely to be not the same thread
     if (!isSingleUpdate)
         QMetaObject::invokeMethod(source, "processPositionUpdate", Qt::AutoConnection,
@@ -573,6 +637,7 @@ static void positionUpdated(JNIEnv *env, jobject thiz, jobject location,
         QMetaObject::invokeMethod(source, "processSinglePositionUpdate", Qt::AutoConnection,
                               Q_ARG(QGeoPositionInfo, info));
 }
+Q_DECLARE_JNI_NATIVE_METHOD(positionUpdated)
 
 static void locationProvidersDisabled(JNIEnv *env, jobject thiz, jint androidClassKey)
 {
@@ -588,6 +653,7 @@ static void locationProvidersDisabled(JNIEnv *env, jobject thiz, jint androidCla
 
     QMetaObject::invokeMethod(source, "locationProviderDisabled", Qt::AutoConnection);
 }
+Q_DECLARE_JNI_NATIVE_METHOD(locationProvidersDisabled)
 
 static void locationProvidersChanged(JNIEnv *env, jobject thiz, jint androidClassKey)
 {
@@ -601,6 +667,7 @@ static void locationProvidersChanged(JNIEnv *env, jobject thiz, jint androidClas
 
     QMetaObject::invokeMethod(source, "locationProvidersChanged", Qt::AutoConnection);
 }
+Q_DECLARE_JNI_NATIVE_METHOD(locationProvidersChanged)
 
 static void notifySatelliteInfoUpdated(const QList<QGeoSatelliteInfo> &inView,
                                        const QList<QGeoSatelliteInfo> &inUse,
@@ -618,7 +685,8 @@ static void notifySatelliteInfoUpdated(const QList<QGeoSatelliteInfo> &inView,
                               Q_ARG(bool, isSingleUpdate));
 }
 
-static void satelliteGpsUpdated(JNIEnv *env, jobject thiz, jobjectArray satellites,
+static void satelliteGpsUpdated(JNIEnv *env, jobject thiz,
+                                jobjectArray satellites,
                                 jint androidClassKey, jboolean isSingleUpdate)
 {
     Q_UNUSED(thiz);
@@ -628,8 +696,9 @@ static void satelliteGpsUpdated(JNIEnv *env, jobject thiz, jobjectArray satellit
 
     notifySatelliteInfoUpdated(sats, inUse, androidClassKey, isSingleUpdate);
 }
+Q_DECLARE_JNI_NATIVE_METHOD(satelliteGpsUpdated)
 
-static void satelliteGnssUpdated(JNIEnv *env, jobject thiz, jobject gnssStatus,
+static void satelliteGnssUpdated(JNIEnv *env, jobject thiz, QtJniTypes::GnssStatus gnssStatus,
                                  jint androidClassKey, jboolean isSingleUpdate)
 {
     Q_UNUSED(env);
@@ -637,60 +706,59 @@ static void satelliteGnssUpdated(JNIEnv *env, jobject thiz, jobject gnssStatus,
 
     QList<QGeoSatelliteInfo> inUse;
     QList<QGeoSatelliteInfo> sats =
-            AndroidPositioning::satelliteInfoFromJavaGnssStatus(gnssStatus, &inUse);
+            AndroidPositioning::satelliteInfoFromJavaGnssStatus(gnssStatus.object(), &inUse);
 
     notifySatelliteInfoUpdated(sats, inUse, androidClassKey, isSingleUpdate);
 }
+Q_DECLARE_JNI_NATIVE_METHOD(satelliteGnssUpdated)
 
-#define GET_AND_CHECK_STATIC_METHOD(VAR, CLASS, METHOD_NAME, METHOD_SIGNATURE)                     \
-    VAR = env.findStaticMethod(CLASS, METHOD_NAME, METHOD_SIGNATURE);                              \
-    if (!VAR) {                                                                                    \
-        __android_log_print(ANDROID_LOG_FATAL, logTag, methodErrorMsg, METHOD_NAME,                \
-                            METHOD_SIGNATURE);                                                     \
-        return false;                                                                              \
+#define GET_AND_CHECK_STATIC_METHOD(VAR, METHOD_NAME, ...)                                  \
+    VAR = env.findStaticMethod<__VA_ARGS__>(positioningClass(),  METHOD_NAME);              \
+    if (!VAR) {                                                                             \
+        __android_log_print(ANDROID_LOG_FATAL, logTag, methodErrorMsg, METHOD_NAME,         \
+                            QtJniTypes::methodSignature<__VA_ARGS__>().data());             \
+        return false;                                                                       \
     }
 
 static bool registerNatives()
 {
-     const JNINativeMethod methods[] = {
-        {"positionUpdated", "(Landroid/location/Location;IZ)V", (void *)positionUpdated},
-        {"locationProvidersDisabled", "(I)V", (void *) locationProvidersDisabled},
-        {"satelliteGpsUpdated", "([Landroid/location/GpsSatellite;IZ)V", (void *)satelliteGpsUpdated},
-        {"locationProvidersChanged", "(I)V", (void *) locationProvidersChanged},
-        {"satelliteGnssUpdated", "(Landroid/location/GnssStatus;IZ)V", (void *)satelliteGnssUpdated}
-    };
-
     QJniEnvironment env;
     if (!env.jniEnv()) {
         __android_log_print(ANDROID_LOG_FATAL, logTag, "Failed to create environment");
         return false;
     }
 
-    if (!positioningClass.init("org/qtproject/qt/android/positioning/QtPositioning")) {
+    if (!positioningClass.init()) {
         __android_log_print(ANDROID_LOG_FATAL, logTag, "Failed to create global class ref");
         return false;
     }
 
-    if (!env.registerNativeMethods(positioningClass(), methods,
-                                   sizeof(methods) / sizeof(methods[0]))) {
+    if (!env.registerNativeMethods(positioningClass(), {
+                                      Q_JNI_NATIVE_METHOD(positionUpdated),
+                                      Q_JNI_NATIVE_METHOD(locationProvidersDisabled),
+                                      Q_JNI_NATIVE_METHOD(satelliteGpsUpdated),
+                                      Q_JNI_NATIVE_METHOD(locationProvidersChanged),
+                                      Q_JNI_NATIVE_METHOD(satelliteGnssUpdated)
+                                  })) {
         __android_log_print(ANDROID_LOG_FATAL, logTag, "Failed to register native methods");
         return false;
     }
 
-    GET_AND_CHECK_STATIC_METHOD(providerListMethodId, positioningClass(), "providerList", "()[I");
-    GET_AND_CHECK_STATIC_METHOD(lastKnownPositionMethodId, positioningClass(), "lastKnownPosition",
-                                "(Z)Landroid/location/Location;");
-    GET_AND_CHECK_STATIC_METHOD(startUpdatesMethodId, positioningClass(), "startUpdates", "(III)I");
-    GET_AND_CHECK_STATIC_METHOD(stopUpdatesMethodId, positioningClass(), "stopUpdates", "(I)V");
-    GET_AND_CHECK_STATIC_METHOD(requestUpdateMethodId, positioningClass(), "requestUpdate",
-                                "(II)I");
-    GET_AND_CHECK_STATIC_METHOD(startSatelliteUpdatesMethodId, positioningClass(),
-                                "startSatelliteUpdates", "(IIZ)I");
+    GET_AND_CHECK_STATIC_METHOD(providerListMethodId, "providerList", jintArray);
+    GET_AND_CHECK_STATIC_METHOD(lastKnownPositionMethodId, "lastKnownPosition",
+                                QtJniTypes::Location, bool, bool);
+    GET_AND_CHECK_STATIC_METHOD(startUpdatesMethodId, "startUpdates", jint, jint, jint, jint,
+                                bool);
+    GET_AND_CHECK_STATIC_METHOD(stopUpdatesMethodId, "stopUpdates", void, jint);
+    GET_AND_CHECK_STATIC_METHOD(requestUpdateMethodId, "requestUpdate", jint, jint, jint, jint,
+                                bool);
+    GET_AND_CHECK_STATIC_METHOD(startSatelliteUpdatesMethodId, "startSatelliteUpdates",
+                                jint, jint, jint, bool);
 
     return true;
 }
 
-Q_DECL_EXPORT jint JNICALL JNI_OnLoad(JavaVM * /*vm*/, void * /*reserved*/)
+extern "C" Q_DECL_EXPORT jint JNICALL JNI_OnLoad(JavaVM * /*vm*/, void * /*reserved*/)
 {
     static bool initialized = false;
     if (initialized)
@@ -699,6 +767,9 @@ Q_DECL_EXPORT jint JNICALL JNI_OnLoad(JavaVM * /*vm*/, void * /*reserved*/)
 
     __android_log_print(ANDROID_LOG_INFO, logTag, "Positioning start");
 
+    const auto context = QNativeInterface::QAndroidApplication::context();
+    QtJniTypes::QtPositioning::callStaticMethod<void>("setContext", context);
+
     if (!registerNatives()) {
         __android_log_print(ANDROID_LOG_FATAL, logTag, "registerNatives() failed");
         return -1;
@@ -712,4 +783,3 @@ Q_DECL_EXPORT jint JNICALL JNI_OnLoad(JavaVM * /*vm*/, void * /*reserved*/)
 
     return JNI_VERSION_1_6;
 }
-
