@@ -73,8 +73,7 @@ QGeoMercatorCoordinatePrivate::~QGeoMercatorCoordinatePrivate()
 
     Azimuth in this context is equivalent to a compass bearing based on true north.
 
-    This class is a \l Q_GADGET since Qt 5.5. It can be
-    \l{Cpp_value_integration_positioning}{directly used from C++ and QML}.
+    This class is also accessible in QML as \l[QML]{geoCoordinate}.
 */
 
 /*!
@@ -658,11 +657,11 @@ QString QGeoCoordinate::toString(CoordinateFormat format) const
 bool QGeoCoordinate::equals(const QGeoCoordinate &lhs, const QGeoCoordinate &rhs)
 {
     bool latEqual = (qIsNaN(lhs.d->lat) && qIsNaN(rhs.d->lat))
-                        || qFuzzyCompare(lhs.d->lat, rhs.d->lat);
+                        || QtPrivate::fuzzyCompare(lhs.d->lat, rhs.d->lat);
     bool lngEqual = (qIsNaN(lhs.d->lng) && qIsNaN(rhs.d->lng))
-                        || qFuzzyCompare(lhs.d->lng, rhs.d->lng);
+                        || QtPrivate::fuzzyCompare(lhs.d->lng, rhs.d->lng);
     bool altEqual = (qIsNaN(lhs.d->alt) && qIsNaN(rhs.d->alt))
-                        || qFuzzyCompare(lhs.d->alt, rhs.d->alt);
+                        || QtPrivate::fuzzyCompare(lhs.d->alt, rhs.d->alt);
 
     if (!qIsNaN(lhs.d->lat) && ((lhs.d->lat == 90.0) || (lhs.d->lat == -90.0)))
         lngEqual = true;
