@@ -283,6 +283,65 @@ void tst_QGeoPath::contains_data()
     QTest::newRow("Not so far away") << c << 0.0 << QGeoCoordinate(0.8, 0.8) << false;
     QTest::newRow("Not so far away and thick line")
             << c << 100000.0 << QGeoCoordinate(0.8, 0.8) << true;
+
+    // Test case from QTBUG-142317
+    QTest::newRow("coord-lon-left-from-path-no-wrap-needed")
+            << QList{QGeoCoordinate(50, 7), QGeoCoordinate(52, 6.999)} << 10000.0
+            << QGeoCoordinate(51, 6.95) << true;
+
+    // Testing various cases:
+    // - wrapped line, need to wrap the coord
+    // - wrapped line, no need to wrap the coord
+    // - non-wrapped line, need to wrap the coord
+    // - non-wrapped line, no need to wrap the coord
+
+    const qreal width{10000.0};
+    const QList<QGeoCoordinate> wrappedPath {
+        QGeoCoordinate(50, 179.95),
+        QGeoCoordinate(52, -179.95)
+    };
+
+    QTest::newRow("wrap-path-no-wrap-coord")
+            << wrappedPath << width << QGeoCoordinate(50.2, 179.94) << true;
+    QTest::newRow("wrap-path-wrap-coord")
+            << wrappedPath << width << QGeoCoordinate(52, -179.98) << true;
+
+    // As close to the 180/-180 wrap line as possible
+    const QList<QGeoCoordinate> notWrappedPathWest {
+        QGeoCoordinate(50, -179.99),
+        QGeoCoordinate(52, -179.98)
+    };
+
+    QTest::newRow("no-wrap-path-no-wrap-coord")
+            << notWrappedPathWest << width << QGeoCoordinate(50.2, -180.0) << true;
+    QTest::newRow("no-wrap-path-wrap-coord-subtract")
+            << notWrappedPathWest << width << QGeoCoordinate(50.5, 179.99) << true;
+
+    const QList<QGeoCoordinate> notWrappedPathEast {
+        QGeoCoordinate(50, 179.99),
+        QGeoCoordinate(52, 179.98)
+    };
+
+    QTest::newRow("no-wrap-path-wrap-coord-add")
+            << notWrappedPathEast << width << QGeoCoordinate(50.5, -179.99) << true;
+
+    const QList<QGeoCoordinate> cycledOverlap {
+        QGeoCoordinate(-70, 171), // i.e. -189
+        QGeoCoordinate(-50, -135), // Each step is + (20, 54)
+        QGeoCoordinate(-30, -81),
+        QGeoCoordinate(-10, -27),
+        QGeoCoordinate(10, 27),
+        QGeoCoordinate(30, 81),
+        QGeoCoordinate(50, 135), // (58, 153) is near this last step
+        QGeoCoordinate(70, -171), // i.e. 189
+    };
+    // Bounding box is -70 <= lat <= 70, 171 <= lon <= -171 = 189 ;^>
+
+    QTest::newRow("cycled-wrap")
+            << cycledOverlap << qreal(23000) << QGeoCoordinate(58, 153) << true;
+    // Witness:
+    // QWebMercator::coordinateInterpolation(QGC(50, 135), QGC(70, -171), 1./3); is QGC(58.094, 153)
+    QCOMPARE_LT(QGeoCoordinate(58, 153).distanceTo(QGeoCoordinate(58.094, 153)), 11000);
 }
 
 void tst_QGeoPath::contains()
